CLI
===

Command-line interface modules.

.. module:: numistalib.cli

Main Entry Point
----------------

.. automodule:: numistalib.cli.main
   :members:
   :undoc-members:

Types Commands
--------------

.. automodule:: numistalib.cli.types
   :members:
   :undoc-members:

Catalogues Commands
-------------------

.. automodule:: numistalib.cli.catalogues
   :members:
   :undoc-members:

Issuers Commands
----------------

.. automodule:: numistalib.cli.issuers
   :members:
   :undoc-members:

Issues Commands
---------------

.. automodule:: numistalib.cli.issues
   :members:
   :undoc-members:

Mints Commands
--------------

.. automodule:: numistalib.cli.mints
   :members:
   :undoc-members:

Collections Commands
--------------------

.. automodule:: numistalib.cli.collections
   :members:
   :undoc-members:

Image Search Commands
---------------------

.. automodule:: numistalib.cli.image_search
   :members:
   :undoc-members:

Literature Commands
-------------------

.. automodule:: numistalib.cli.literature
   :members:
   :undoc-members:

Prices Commands
---------------

.. automodule:: numistalib.cli.prices
   :members:
   :undoc-members:

Users Commands
--------------

.. automodule:: numistalib.cli.users
   :members:
   :undoc-members:

Config Commands
---------------

.. automodule:: numistalib.cli.config
   :members:
   :undoc-members:

Theme
-----

.. automodule:: numistalib.cli.theme
   :members:
   :undoc-members:
